pulsarbat
=========

Pulsarbat (PULSAR Baseband Analysis Tools) is a package for analysis of baseband observations of pulsars. The ultimate goal of this package is
to allow users to process radio pulsar data in an interactive and
"embarassingly parallel" manner (via Dask_).

The source code can be found on GitHub: https://github.com/theXYZT/pulsarbat

Pulsarbat is licensed under the GNU General Public License v3.

.. _Dask: https://dask.org/


Quickstart
----------

Install the latest version of Pulsarbat:

.. code-block:: console

    $ pip install pulsarbat

To use pulsarbat in a project::

    import pulsarbat as pb



.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Getting Started

   install.rst
   usage.rst
   contributing.rst


.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: API Reference

   api/index.rst
   history.rst
